@@ -1,5 +1,17 @@
-#include "libslic3r/GCode/SeamChoice.hpp"
 #include <random>
+#include <cstddef>
+#include <optional>
+#include <vector>
+
+#include "libslic3r/GCode/SeamChoice.hpp"
+#include "libslic3r/GCode/SeamPerimeters.hpp"
+
+namespace Slic3r {
+namespace Seams {
+struct SeamChoice;
+struct SeamPerimeterChoice;
+}  // namespace Seams
+}  // namespace Slic3r
 
 namespace Slic3r::Seams::Random {
 namespace Impl {
