@@ -1,10 +1,28 @@
 #include "Travels.hpp"
 
+#include <boost/math/special_functions/pow.hpp>
+#include <algorithm>
+#include <cmath>
+#include <limits>
+#include <tuple>
+#include <utility>
+#include <cassert>
+#include <cinttypes>
+
 #include "libslic3r/PrintConfig.hpp"
 #include "libslic3r/Layer.hpp"
 #include "libslic3r/Print.hpp"
-
 #include "../GCode.hpp"
+#include "libslic3r/ExPolygon.hpp"
+#include "libslic3r/Exception.hpp"
+#include "libslic3r/ExtrusionEntity.hpp"
+#include "libslic3r/ExtrusionEntityCollection.hpp"
+#include "libslic3r/LayerRegion.hpp"
+#include "libslic3r/Polygon.hpp"
+#include "libslic3r/Polyline.hpp"
+#include "libslic3r/libslic3r.h"
+#include "tcbspan/span.hpp"
+#include "libslic3r/ShortestPath.hpp"
 
 namespace Slic3r::GCode {
 
