@@ -2,41 +2,60 @@
 ///|/
 ///|/ PrusaSlicer is released under the terms of the AGPLv3 or higher
 ///|/
-#include <unordered_set>
-
 #include <libslic3r/Exception.hpp>
 #include <libslic3r/SLAPrintSteps.hpp>
 #include <libslic3r/MeshBoolean.hpp>
 #include <libslic3r/TriangleMeshSlicer.hpp>
-
-// Need the cylinder method for the the drainholes in hollowing step
-#include <libslic3r/SLA/SupportTreeBuilder.hpp>
-
 #include <libslic3r/Execution/ExecutionTBB.hpp>
 #include <libslic3r/SLA/Pad.hpp>
 #include <libslic3r/SLA/SupportPointGenerator.hpp>
 #include <libslic3r/SLA/ZCorrection.hpp>
-
 #include <libslic3r/ElephantFootCompensation.hpp>
-#include <libslic3r/AABBTreeIndirect.hpp>
-#include <libslic3r/MeshSplitImpl.hpp>
-#include <libslic3r/SlicesToTriangleMesh.hpp>
 #include <libslic3r/CSGMesh/ModelToCSGMesh.hpp>
 #include <libslic3r/CSGMesh/SliceCSGMesh.hpp>
 #include <libslic3r/CSGMesh/VoxelizeCSGMesh.hpp>
 #include <libslic3r/CSGMesh/PerformCSGMeshBooleans.hpp>
 #include <libslic3r/OpenVDBUtils.hpp>
 #include <libslic3r/QuadricEdgeCollapse.hpp>
-
 #include <libslic3r/ClipperUtils.hpp>
+#include <chrono>
+#include <algorithm>
+#include <array>
+#include <cmath>
+#include <functional>
+#include <iterator>
+#include <limits>
+#include <map>
+#include <memory>
+#include <mutex>
+#include <numeric>
+#include <set>
+#include <tuple>
+#include <vector>
+#include <cassert>
 //#include <libslic3r/ShortEdgeCollapse.hpp>
 
 #include <boost/log/trivial.hpp>
 
 #include "I18N.hpp"
-
-#include <libnest2d/tools/benchmark.h>
 #include "format.hpp"
+#include "libslic3r/BoundingBox.hpp"
+#include "libslic3r/CSGMesh/CSGMesh.hpp"
+#include "libslic3r/ExPolygon.hpp"
+#include "libslic3r/Execution/Execution.hpp"
+#include "libslic3r/Model.hpp"
+#include "libslic3r/Point.hpp"
+#include "libslic3r/Polygon.hpp"
+#include "libslic3r/PrintBase.hpp"
+#include "libslic3r/PrintConfig.hpp"
+#include "libslic3r/SLA/Hollowing.hpp"
+#include "libslic3r/SLA/JobController.hpp"
+#include "libslic3r/SLA/RasterBase.hpp"
+#include "libslic3r/SLA/SupportPoint.hpp"
+#include "libslic3r/SLA/SupportTree.hpp"
+#include "libslic3r/SLA/SupportTreeStrategies.hpp"
+#include "libslic3r/SLAPrint.hpp"
+#include "libslic3r/TriangleMesh.hpp"
 
 namespace Slic3r {
 
@@ -167,9 +186,9 @@ indexed_triangle_set SLAPrint::Steps::generate_preview_vdb(
 
 void SLAPrint::Steps::generate_preview(SLAPrintObject &po, SLAPrintObjectStep step)
 {
-    Benchmark bench;
+    using std::chrono::high_resolution_clock;
 
-    bench.start();
+    auto start{high_resolution_clock::now()};
 
     auto r = range(po.m_mesh_to_slice);
     auto m = indexed_triangle_set{};
@@ -284,11 +303,14 @@ void SLAPrint::Steps::generate_preview(SLAPrintObject &po, SLAPrintObjectStep st
         po.m_preview_meshes[i] = {};
     }
 
-    bench.stop();
+    auto stop{high_resolution_clock::now()};
 
-    if (!po.m_preview_meshes[step]->empty())
-        BOOST_LOG_TRIVIAL(trace) << "Preview gen took: " << bench.getElapsedSec();
-    else
+    if (!po.m_preview_meshes[step]->empty()) {
+        using std::chrono::duration;
+        using std::chrono::seconds;
+
+        BOOST_LOG_TRIVIAL(trace) << "Preview gen took: " << duration<double>{stop - start}.count();
+    } else
         BOOST_LOG_TRIVIAL(error) << "Preview failed!";
 
     using namespace std::string_literals;
