@@ -108,7 +108,6 @@ void GLModel::Geometry::add_vertex(const Vec3f& position, const Vec3f& normal, c
     vertices.emplace_back(tex_coord.y());
 }
 
-#if ENABLE_OPENGL_ES
 void GLModel::Geometry::add_vertex(const Vec3f& position, const Vec3f& normal, const Vec3f& extra)
 {
     assert(format.vertex_layout == EVertexLayout::P3N3E3);
@@ -122,7 +121,6 @@ void GLModel::Geometry::add_vertex(const Vec3f& position, const Vec3f& normal, c
     vertices.emplace_back(extra.y());
     vertices.emplace_back(extra.z());
 }
-#endif // ENABLE_OPENGL_ES
 
 void GLModel::Geometry::add_vertex(const Vec4f& position)
 {
@@ -279,9 +277,7 @@ size_t GLModel::Geometry::vertex_stride_floats(const Format& format)
     case EVertexLayout::P3T2:   { return 5; }
     case EVertexLayout::P3N3:   { return 6; }
     case EVertexLayout::P3N3T2: { return 8; }
-#if ENABLE_OPENGL_ES
     case EVertexLayout::P3N3E3: { return 9; }
-#endif // ENABLE_OPENGL_ES
     case EVertexLayout::P4:     { return 4; }
     default:                    { assert(false); return 0; }
     };
@@ -296,12 +292,8 @@ size_t GLModel::Geometry::position_stride_floats(const Format& format)
     case EVertexLayout::P3:
     case EVertexLayout::P3T2:
     case EVertexLayout::P3N3:
-#if ENABLE_OPENGL_ES
     case EVertexLayout::P3N3T2:
     case EVertexLayout::P3N3E3: { return 3; }
-#else
-    case EVertexLayout::P3N3T2: { return 3; }
-#endif // ENABLE_OPENGL_ES
     case EVertexLayout::P4:     { return 4; }
     default:                    { assert(false); return 0; }
     };
@@ -317,9 +309,7 @@ size_t GLModel::Geometry::position_offset_floats(const Format& format)
     case EVertexLayout::P3T2:
     case EVertexLayout::P3N3:
     case EVertexLayout::P3N3T2:
-#if ENABLE_OPENGL_ES
     case EVertexLayout::P3N3E3:
-#endif // ENABLE_OPENGL_ES
     case EVertexLayout::P4:   { return 0; }
     default:                  { assert(false); return 0; }
     };
@@ -330,12 +320,8 @@ size_t GLModel::Geometry::normal_stride_floats(const Format& format)
     switch (format.vertex_layout)
     {
     case EVertexLayout::P3N3:
-#if ENABLE_OPENGL_ES
     case EVertexLayout::P3N3T2:
     case EVertexLayout::P3N3E3: { return 3; }
-#else
-    case EVertexLayout::P3N3T2: { return 3; }
-#endif // ENABLE_OPENGL_ES
     default:                    { assert(false); return 0; }
     };
 }
@@ -345,12 +331,8 @@ size_t GLModel::Geometry::normal_offset_floats(const Format& format)
     switch (format.vertex_layout)
     {
     case EVertexLayout::P3N3:
-#if ENABLE_OPENGL_ES
     case EVertexLayout::P3N3T2:
     case EVertexLayout::P3N3E3: { return 3; }
-#else
-    case EVertexLayout::P3N3T2: { return 3; }
-#endif // ENABLE_OPENGL_ES
     default:                    { assert(false); return 0; }
     };
 }
@@ -377,7 +359,6 @@ size_t GLModel::Geometry::tex_coord_offset_floats(const Format& format)
     };
 }
 
-#if ENABLE_OPENGL_ES
 size_t GLModel::Geometry::extra_stride_floats(const Format& format)
 {
     switch (format.vertex_layout)
@@ -395,7 +376,6 @@ size_t GLModel::Geometry::extra_offset_floats(const Format& format)
     default:                    { assert(false); return 0; }
     };
 }
-#endif // ENABLE_OPENGL_ES
 
 size_t GLModel::Geometry::index_stride_bytes(const Geometry& data)
 {
@@ -418,9 +398,7 @@ bool GLModel::Geometry::has_position(const Format& format)
     case EVertexLayout::P3T2:
     case EVertexLayout::P3N3:
     case EVertexLayout::P3N3T2:
-#if ENABLE_OPENGL_ES
     case EVertexLayout::P3N3E3:
-#endif // ENABLE_OPENGL_ES
     case EVertexLayout::P4:   { return true; }
     default:                  { assert(false); return false; }
     };
@@ -436,12 +414,8 @@ bool GLModel::Geometry::has_normal(const Format& format)
     case EVertexLayout::P3T2:
     case EVertexLayout::P4:     { return false; }
     case EVertexLayout::P3N3:
-#if ENABLE_OPENGL_ES
     case EVertexLayout::P3N3T2:
     case EVertexLayout::P3N3E3: { return true; }
-#else
-    case EVertexLayout::P3N3T2: { return true; }
-#endif // ENABLE_OPENGL_ES
     default:                    { assert(false); return false; }
     };
 }
@@ -456,15 +430,12 @@ bool GLModel::Geometry::has_tex_coord(const Format& format)
     case EVertexLayout::P2:
     case EVertexLayout::P3:
     case EVertexLayout::P3N3:
-#if ENABLE_OPENGL_ES
     case EVertexLayout::P3N3E3:
-#endif // ENABLE_OPENGL_ES
     case EVertexLayout::P4:     { return false; }
     default:                    { assert(false); return false; }
     };
 }
 
-#if ENABLE_OPENGL_ES
 bool GLModel::Geometry::has_extra(const Format& format)
 {
     switch (format.vertex_layout)
@@ -480,7 +451,6 @@ bool GLModel::Geometry::has_extra(const Format& format)
     default:                    { assert(false); return false; }
     };
 }
-#endif // ENABLE_OPENGL_ES
 
 #if ENABLE_GLMODEL_STATISTICS
 GLModel::Statistics GLModel::s_statistics;
@@ -715,12 +685,16 @@ void GLModel::reset()
         s_statistics.gpu_memory.vertices.current -= vertices_size_bytes();
 #endif // ENABLE_GLMODEL_STATISTICS
     }
-#if ENABLE_GL_CORE_PROFILE
-    if (m_render_data.vao_id > 0) {
-        glsafe(::glDeleteVertexArrays(1, &m_render_data.vao_id));
-        m_render_data.vao_id = 0;
+#if !SLIC3R_OPENGL_ES
+    if (OpenGLManager::get_gl_info().is_core_profile()) {
+#endif // !SLIC3R_OPENGL_ES
+        if (m_render_data.vao_id > 0) {
+            glsafe(::glDeleteVertexArrays(1, &m_render_data.vao_id));
+            m_render_data.vao_id = 0;
+        }
+#if !SLIC3R_OPENGL_ES
     }
-#endif // ENABLE_GL_CORE_PROFILE
+#endif // !SLIC3R_OPENGL_ES
 
     m_render_data.vertices_count = 0;
     m_render_data.indices_count  = 0;
@@ -788,23 +762,22 @@ void GLModel::render(const std::pair<size_t, size_t>& range)
     const bool position = Geometry::has_position(data.format);
     const bool normal = Geometry::has_normal(data.format);
     const bool tex_coord = Geometry::has_tex_coord(data.format);
-#if ENABLE_OPENGL_ES
     const bool extra = Geometry::has_extra(data.format);
-#endif // ENABLE_OPENGL_ES
 
-#if ENABLE_GL_CORE_PROFILE
-    if (OpenGLManager::get_gl_info().is_version_greater_or_equal_to(3, 0))
+#if !SLIC3R_OPENGL_ES
+    if (OpenGLManager::get_gl_info().is_core_profile()) {
+#endif // !SLIC3R_OPENGL_ES
         glsafe(::glBindVertexArray(m_render_data.vao_id));
+#if !SLIC3R_OPENGL_ES
+    }
+#endif // !SLIC3R_OPENGL_ES
     // the following binding is needed to set the vertex attributes
-#endif // ENABLE_GL_CORE_PROFILE
     glsafe(::glBindBuffer(GL_ARRAY_BUFFER, m_render_data.vbo_id));
 
     int position_id  = -1;
     int normal_id    = -1;
     int tex_coord_id = -1;
-#if ENABLE_OPENGL_ES
     int extra_id     = -1;
-#endif // ENABLE_OPENGL_ES
 
     if (position) {
         position_id = shader->get_attrib_location("v_position");
@@ -827,7 +800,6 @@ void GLModel::render(const std::pair<size_t, size_t>& range)
             glsafe(::glEnableVertexAttribArray(tex_coord_id));
         }
     }
-#if ENABLE_OPENGL_ES
     if (extra) {
         extra_id = shader->get_attrib_location("v_extra");
         if (extra_id != -1) {
@@ -835,23 +807,14 @@ void GLModel::render(const std::pair<size_t, size_t>& range)
             glsafe(::glEnableVertexAttribArray(extra_id));
         }
     }
-#endif // ENABLE_OPENGL_ES
 
     shader->set_uniform("uniform_color", data.color);
 
-#if ENABLE_GL_CORE_PROFILE
-    if (!OpenGLManager::get_gl_info().is_version_greater_or_equal_to(3, 0))
-#endif // ENABLE_GL_CORE_PROFILE
-        glsafe(::glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, m_render_data.ibo_id));
+    glsafe(::glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, m_render_data.ibo_id));
     glsafe(::glDrawElements(mode, range.second - range.first, index_type, (const void*)(range.first * Geometry::index_stride_bytes(data))));
-#if !ENABLE_GL_CORE_PROFILE
-    glsafe(::glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, 0));
-#endif // !ENABLE_GL_CORE_PROFILE
 
-#if ENABLE_OPENGL_ES
     if (extra_id != -1)
         glsafe(::glDisableVertexAttribArray(extra_id));
-#endif // ENABLE_OPENGL_ES
     if (tex_coord_id != -1)
         glsafe(::glDisableVertexAttribArray(tex_coord_id));
     if (normal_id != -1)
@@ -860,10 +823,13 @@ void GLModel::render(const std::pair<size_t, size_t>& range)
         glsafe(::glDisableVertexAttribArray(position_id));
 
     glsafe(::glBindBuffer(GL_ARRAY_BUFFER, 0));
-#if ENABLE_GL_CORE_PROFILE
-    if (OpenGLManager::get_gl_info().is_version_greater_or_equal_to(3, 0))
+#if !SLIC3R_OPENGL_ES
+    if (OpenGLManager::get_gl_info().is_core_profile()) {
+#endif // !SLIC3R_OPENGL_ES
         glsafe(::glBindVertexArray(0));
-#endif // ENABLE_GL_CORE_PROFILE
+#if !SLIC3R_OPENGL_ES
+    }
+#endif // !SLIC3R_OPENGL_ES
 
 #if ENABLE_GLMODEL_STATISTICS
     ++s_statistics.render_calls;
@@ -896,10 +862,13 @@ void GLModel::render_instanced(unsigned int instances_vbo, unsigned int instance
             return;
     }
 
-#if ENABLE_GL_CORE_PROFILE
-    if (OpenGLManager::get_gl_info().is_version_greater_or_equal_to(3, 0))
+#if !SLIC3R_OPENGL_ES
+    if (OpenGLManager::get_gl_info().is_core_profile()) {
+#endif // !SLIC3R_OPENGL_ES
         glsafe(::glBindVertexArray(m_render_data.vao_id));
-#endif // ENABLE_GL_CORE_PROFILE
+#if !SLIC3R_OPENGL_ES
+    }
+#endif // !SLIC3R_OPENGL_ES
 
     glsafe(::glBindBuffer(GL_ARRAY_BUFFER, instances_vbo));
     const size_t instance_stride = 5 * sizeof(float);
@@ -920,9 +889,7 @@ void GLModel::render_instanced(unsigned int instances_vbo, unsigned int instance
     const bool position = Geometry::has_position(data.format);
     const bool normal   = Geometry::has_normal(data.format);
 
-#if ENABLE_GL_CORE_PROFILE
     // the following binding is needed to set the vertex attributes
-#endif // ENABLE_GL_CORE_PROFILE
     glsafe(::glBindBuffer(GL_ARRAY_BUFFER, m_render_data.vbo_id));
 
     if (position) {
@@ -937,13 +904,7 @@ void GLModel::render_instanced(unsigned int instances_vbo, unsigned int instance
 
     shader->set_uniform("uniform_color", data.color);
 
-#if !ENABLE_GL_CORE_PROFILE
-    glsafe(::glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, m_render_data.ibo_id));
-#endif // !ENABLE_GL_CORE_PROFILE
     glsafe(::glDrawElementsInstanced(mode, indices_count(), index_type, (const void*)0, instances_count));
-#if !ENABLE_GL_CORE_PROFILE
-    glsafe(::glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, 0));
-#endif // !ENABLE_GL_CORE_PROFILE
 
     if (normal)
         glsafe(::glDisableVertexAttribArray(normal_id));
@@ -954,10 +915,13 @@ void GLModel::render_instanced(unsigned int instances_vbo, unsigned int instance
     glsafe(::glDisableVertexAttribArray(offset_id));
 
     glsafe(::glBindBuffer(GL_ARRAY_BUFFER, 0));
-#if ENABLE_GL_CORE_PROFILE
-    if (OpenGLManager::get_gl_info().is_version_greater_or_equal_to(3, 0))
+#if !SLIC3R_OPENGL_ES
+    if (OpenGLManager::get_gl_info().is_core_profile()) {
+#endif // !SLIC3R_OPENGL_ES
         glsafe(::glBindVertexArray(0));
-#endif // ENABLE_GL_CORE_PROFILE
+#if !SLIC3R_OPENGL_ES
+    }
+#endif // !SLIC3R_OPENGL_ES
 
 #if ENABLE_GLMODEL_STATISTICS
     ++s_statistics.render_instanced_calls;
@@ -977,12 +941,14 @@ bool GLModel::send_to_gpu()
         return false;
     }
 
-#if ENABLE_GL_CORE_PROFILE
-    if (OpenGLManager::get_gl_info().is_version_greater_or_equal_to(3, 0)) {
+#if !SLIC3R_OPENGL_ES
+    if (OpenGLManager::get_gl_info().is_core_profile()) {
+#endif // !SLIC3R_OPENGL_ES
         glsafe(::glGenVertexArrays(1, &m_render_data.vao_id));
         glsafe(::glBindVertexArray(m_render_data.vao_id));
+#if !SLIC3R_OPENGL_ES
     }
-#endif // ENABLE_GL_CORE_PROFILE
+#endif // !SLIC3R_OPENGL_ES
 
     // vertices
     glsafe(::glGenBuffers(1, &m_render_data.vbo_id));
@@ -1023,11 +989,6 @@ bool GLModel::send_to_gpu()
         glsafe(::glBufferData(GL_ELEMENT_ARRAY_BUFFER, data.indices_size_bytes(), data.indices.data(), GL_STATIC_DRAW));
     }
 
-#if ENABLE_GL_CORE_PROFILE
-    if (!OpenGLManager::get_gl_info().is_version_greater_or_equal_to(3, 0))
-#endif // ENABLE_GL_CORE_PROFILE
-        glsafe(::glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, 0));
-
     m_render_data.indices_count = indices_count;
 #if ENABLE_GLMODEL_STATISTICS
     s_statistics.gpu_memory.indices.current += data.indices_size_bytes();
@@ -1035,10 +996,13 @@ bool GLModel::send_to_gpu()
 #endif // ENABLE_GLMODEL_STATISTICS
     data.indices = std::vector<unsigned int>();
 
-#if ENABLE_GL_CORE_PROFILE
-    if (OpenGLManager::get_gl_info().is_version_greater_or_equal_to(3, 0))
+#if !SLIC3R_OPENGL_ES
+    if (OpenGLManager::get_gl_info().is_core_profile()) {
+#endif // !SLIC3R_OPENGL_ES
         glsafe(::glBindVertexArray(0));
-#endif // ENABLE_GL_CORE_PROFILE
+#if !SLIC3R_OPENGL_ES
+    }
+#endif // !SLIC3R_OPENGL_ES
 
     return true;
 }
