@@ -37,6 +37,7 @@
 #include "../Utils/PrintHost.hpp"
 #include "../Utils/FixModelByWin10.hpp"
 #include "../Utils/UndoRedo.hpp"
+#include "../Utils/ServiceConfig.hpp"
 #include "RemovableDriveManager.hpp"
 #include "BitmapCache.hpp"
 #include "BonjourDialog.hpp"
@@ -653,7 +654,7 @@ void PhysicalPrinterDialog::update(bool printer_change)
             text_ctrl* printhost_win = printhost_field ? dynamic_cast<text_ctrl*>(printhost_field->getWindow()) : nullptr;
             if (!m_opened_as_connect && printhost_win && m_last_host_type != htPrusaConnect){
                 m_stored_host = printhost_win->GetValue();
-                printhost_win->SetValue(L"https://connect.prusa3d.com");
+                printhost_win->SetValue(from_u8(Utils::ServiceConfig::instance().connect_url()));
             }
         } else {
             m_printhost_browse_btn->Show();
@@ -727,13 +728,20 @@ void PhysicalPrinterDialog::update_host_type(bool printer_change)
     for (PresetForPrinter* prstft : m_presets) {
         std::string preset_name = prstft->get_preset_name();
         if (Preset* preset = wxGetApp().preset_bundle->printers.find_preset(preset_name)) {
-            std::string model_id = preset->config.opt_string("printer_model");            
+            std::string model_id = preset->config.opt_string("printer_model"); 
             if (preset->vendor) {
-                if (preset->vendor->name == "Prusa Research") {
+                std::string model_id_no_pref = model_id;
+                std::string vendor_repo_prefix;
+                vendor_repo_prefix = preset->vendor->repo_prefix;
+                if (model_id_no_pref.find(vendor_repo_prefix) == 0) {
+                    model_id_no_pref = model_id_no_pref.substr(vendor_repo_prefix.size());
+                    boost::trim_left(model_id_no_pref);
+                }
+                if (preset->vendor->name.find("Prusa Research") != std::string::npos) {
                     const std::vector<VendorProfile::PrinterModel>& models = preset->vendor->models;
                     auto it = std::find_if(models.begin(), models.end(),
                         [model_id](const VendorProfile::PrinterModel& model) { return model.id == model_id; });
-                    if (it != models.end() && model_supports_prusalink(it->family))
+                    if (it != models.end() && model_supports_prusalink(model_id_no_pref))
                         continue;
                 }
             }
@@ -753,11 +761,16 @@ void PhysicalPrinterDialog::update_host_type(bool printer_change)
             break;
         }
         std::string model_id = preset->config.opt_string("printer_model");
-        if (preset->vendor && preset->vendor->name != "Prusa Research") {
-            connect.supported = false;
-            break;
+        // remove prefix from printer_model
+        if (preset->vendor) {
+            std::string vendor_repo_prefix;
+            vendor_repo_prefix = preset->vendor->repo_prefix;
+            if (model_id.find(vendor_repo_prefix) == 0) {
+                model_id = model_id.substr(vendor_repo_prefix.size());
+                boost::trim_left(model_id);
+            }
         }
-        if (preset->vendor && preset->vendor->name != "Prusa Research") {
+        if (preset->vendor && preset->vendor->name.find("Prusa Research") == std::string::npos) {
             connect.supported = false;
             break;
         }
@@ -888,10 +901,14 @@ void PhysicalPrinterDialog::OnOK(wxEvent& event)
     text_ctrl* printhost_win = printhost_field ? dynamic_cast<text_ctrl*>(printhost_field->getWindow()) : nullptr;
     const auto opt = m_config->option<ConfigOptionEnum<PrintHostType>>("host_type");
     if (opt->value == htPrusaConnect) {
-        if (printhost_win && printhost_win->GetValue() != L"https://connect.prusa3d.com"){
-            InfoDialog msg(this, _L("Warning"), _L("URL of Prusa Connect is different from https://connect.prusa3d.com. Do you want to continue?"), true, wxYES_NO);
+        auto& sc = Utils::ServiceConfig::instance();
+        if (printhost_win && printhost_win->GetValue() != GUI::from_u8(sc.connect_url())){
+            InfoDialog msg(this, _L("Warning"),
+                           // TRN: The placeholder expands to https://connect.prusa3d.com. The warning shows when someone select PrusaConnect physical printer, but enters different URL.
+                           GUI::format(_L("URL of Prusa Connect is different from %1%. Do you want to continue?"),
+                           sc.connect_url()), true, wxYES_NO);
             if(msg.ShowModal() != wxID_YES){
-                printhost_win->SetValue(L"https://connect.prusa3d.com");
+                printhost_win->SetValue(GUI::from_u8(Utils::ServiceConfig::instance().connect_url()));
                 return;
             }
         }
