@@ -101,7 +101,8 @@ std::string get_font_filepath() {
     return resource_dir + "fonts/NotoSans-Regular.ttf";
 }
 
-#include "imgui/imstb_truetype.h"
+// Explicit horror include (used to be implicit) - libslic3r "officialy" does not depend on imgui.
+#include "../../bundled_deps/imgui/imgui/imstb_truetype.h" // stbtt_fontinfo
 TEST_CASE("Read glyph C shape from font, stb library calls ONLY", "[Emboss]") {
     std::string font_path = get_font_filepath();
     char  letter   = 'C';
